import { globalServer } from '../index'

interface Param {
  page: number
  size: number
}

export const getTaskList = (params: Param) =>
  globalServer<{
    tasks: TaskList[]
    total: number
  }>({
    url: 'api/task/summary',
    method: 'get',
    data: params,

  })


export const getTaskInfo = (taskId: string) => globalServer<{ details: TaskInfo[] }>({
  url: 'api/task/detail',
  method: 'GET',
  params: { task: taskId },
})

export interface TaskCreateParams {
  site: string
  devices: {
    sn: string
    disk?: string
    host?: string
  }[],
  mode: 'import' | 'export' | 'update'
  startTime?: string
  endTime?: string
}

export const createTask = (params: TaskCreateParams) => globalServer({
  url: 'api/task/apply',
  method: 'POST',
  data: params,
})

export const cancelTask = (taskId: string) => globalServer({
  url: 'api/task/cancel',
  method: 'POST',
  data: { task: taskId },
})

export type TaskInfo = {
  finish: number;
  id: string;
  info: string;
  site: string;
  sn: string;
  status: -1 | 0 | 1 | 2; // -1 失败, 0 未开始, 1 进行中, 2 成功
  task_id: string;
  total: number;
};

export interface TaskList {
  endTime: string;    // 结束时间（可能是空字符串）
  id: string;         // "task759956"
  info: string;       // ""
  mode: string;       // "export"
  site: string;       // "test1"
  startTime: string;  // 开始时间（可能是空字符串）
  status: -1 | 0 | 1 | 2 | 3; // -1 失败, 0 未开始, 1 进行中, 2 取消, 3 成功
  loading?: boolean
}